Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(149)

Unified Diff: chrome/browser/storage_monitor/storage_monitor_win.h

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage_monitor/storage_monitor_win.h
diff --git a/chrome/browser/storage_monitor/removable_device_notifications_window_win.h b/chrome/browser/storage_monitor/storage_monitor_win.h
similarity index 67%
rename from chrome/browser/storage_monitor/removable_device_notifications_window_win.h
rename to chrome/browser/storage_monitor/storage_monitor_win.h
index 3c049e7e572dd5487e953060c09b052cde4b70dd..235d729f3e2f46337a50cada8f5227d8f366424d 100644
--- a/chrome/browser/storage_monitor/removable_device_notifications_window_win.h
+++ b/chrome/browser/storage_monitor/storage_monitor_win.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
-#define CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
+#ifndef CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_WIN_H_
+#define CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_WIN_H_
#include "base/basictypes.h"
#include "base/memory/ref_counted.h"
@@ -17,27 +17,26 @@ class FilePath;
namespace chrome {
namespace test {
-class TestRemovableDeviceNotificationsWindowWin;
+class TestStorageMonitorWin;
}
class PortableDeviceWatcherWin;
class VolumeMountWatcherWin;
-class RemovableDeviceNotificationsWindowWin : public StorageMonitor {
+class StorageMonitorWin : public StorageMonitor {
public:
- // Creates an instance of RemovableDeviceNotificationsWindowWin. Should only
- // be called by browser start up code. Use GetInstance() instead.
- static RemovableDeviceNotificationsWindowWin* Create();
+ // Creates an instance of StorageMonitorWin. Should only be called by browser
+ // start up code. Use GetInstance() instead.
+ static StorageMonitorWin* Create();
- virtual ~RemovableDeviceNotificationsWindowWin();
+ virtual ~StorageMonitorWin();
// Must be called after the file thread is created.
void Init();
// StorageMonitor:
- virtual bool GetStorageInfoForPath(
- const base::FilePath& path,
- StorageInfo* device_info) const OVERRIDE;
+ virtual bool GetStorageInfoForPath(const base::FilePath& path,
+ StorageInfo* device_info) const OVERRIDE;
virtual bool GetMTPStorageInfoFromDeviceId(
const std::string& storage_device_id,
string16* device_location,
@@ -48,14 +47,13 @@ class RemovableDeviceNotificationsWindowWin : public StorageMonitor {
private:
class PortableDeviceNotifications;
- friend class test::TestRemovableDeviceNotificationsWindowWin;
+ friend class test::TestStorageMonitorWin;
// To support unit tests, this constructor takes |volume_mount_watcher| and
// |portable_device_watcher| objects. These params are either constructed in
- // unit tests or in RemovableDeviceNotificationsWindowWin::Create() function.
- RemovableDeviceNotificationsWindowWin(
- VolumeMountWatcherWin* volume_mount_watcher,
- PortableDeviceWatcherWin* portable_device_watcher);
+ // unit tests or in StorageMonitorWin::Create() function.
+ StorageMonitorWin(VolumeMountWatcherWin* volume_mount_watcher,
+ PortableDeviceWatcherWin* portable_device_watcher);
// Gets the removable storage information given a |device_path|. On success,
// returns true and fills in |device_location|, |unique_id|, |name| and
@@ -89,9 +87,9 @@ class RemovableDeviceNotificationsWindowWin : public StorageMonitor {
// devices.
scoped_ptr<PortableDeviceWatcherWin> portable_device_watcher_;
- DISALLOW_COPY_AND_ASSIGN(RemovableDeviceNotificationsWindowWin);
+ DISALLOW_COPY_AND_ASSIGN(StorageMonitorWin);
};
} // namespace chrome
-#endif // CHROME_BROWSER_STORAGE_MONITOR_REMOVABLE_DEVICE_NOTIFICATIONS_WINDOW_WIN_H_
+#endif // CHROME_BROWSER_STORAGE_MONITOR_STORAGE_MONITOR_WIN_H_
« no previous file with comments | « chrome/browser/storage_monitor/storage_monitor_unittest.cc ('k') | chrome/browser/storage_monitor/storage_monitor_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698